==> todotask2.0.1.zip: todotask2/app/views/grp/mst.php <==
<?php
	// ページ描画
	// ヘッダ
	require_once(TODOTASK_VIEW_DIR.'/common/header.inc.php');

function fBtnchk($flg,$chkval) {
	if($flg==$chkval) {
		print "checked";
	}
}
function fRdo($name, $flg,$on_label,$off_label) {
?>
	<label for="<?php echo $name.VIEW_ON; ?>">
	 <input type="radio" id="<?php echo $name.VIEW_ON; ?>" name="<?php echo $name; ?>" value="<?php echo VIEW_ON; ?>" <?php fBtnchk($flg,VIEW_ON); ?>><?php echo $on_label; ?>
	</label>
	<label for="<?php echo $name.VIEW_OFF; ?>">
	 <input type="radio" id="<?php echo $name.VIEW_OFF; ?>" name="<?php echo $name; ?>" value="<?php echo VIEW_OFF; ?>" <?php fBtnchk($flg,VIEW_OFF); ?>><?php echo $off_label; ?>
	</label>
<?php
}
function fGetOptPriority($cnt,$priority) {
	$tmp = "";
	$selected = "";
	if ($priority == $cnt || ($priority == "" && $cnt == 1 )){
		$selected = "selected";
	}
	for ($i=1;$i<=$cnt;$i++) {
		$tmp .= TASK_PRIORITY;  
	}
	return "<option value=\"".$cnt."\"" . $selected . ">".$tmp."</option>";
}

?>
<div align="center">
<div class="noticediv">
ここでグループの状態を管理することにより、表示状態や機能のon/offをコントロールできます。
</div>

<big class="err_msg"><?php echo $this->art_msg; ?></big>


<form action="./grpmst.php" method="post">

<?php

if ($this->memLv == GRPAUTH_ADMIN) {
?>
	<br>
	<big>このグループの基本情報の更新</big><br>
	<table border="0" cellpadding="1" cellspacing="2">
	<tr><td class="tdview">グループ名：</td><td class="tdview2">
	<input type="text" name="group_name" value="<?php echo $this->aryGrpInfo["group_name"]; ?>"><br>
	</td></tr>

	<tr><td class="tdview">グループ情報：</td><td class="tdview2">
	<input type="text" name="group_note" value="<?php echo $this->aryGrpInfo["group_note"]; ?>"><br>
	</td></tr>
	<tr><td class="tdview">グループ重要度：</td><td class="tdview2">
	<select name="group_prio">
<?php
	for ($j=1;$j<=5;$j++) {
		echo fGetOptPriority($j,$this->aryGrpInfo["group_prio"]);
	}
?>
	</select>
	</td></tr>
	</table>

	<br><small>※グループの脱退や削除はユーザー情報のページからおこなってください。</small><br>
	<input type="submit" name="submit5" value="更新" class="submit">
	<br>
	<br>
<?php
}
?>


<?php
if (count($this->aryOptGrpMem)>0) {
?>
	<br>
	<big>このグループの参加メンバー情報</big><br>
<?php
	$i = 0;
	// 管理者以外変更できないように
	$tmpDis = "DISABLED";
	if (($this->memLv == GRPAUTH_ADMIN)||($this->memLv == GRPAUTH_MADMIN)) {
		$tmpDis = "";
	}
	foreach ($this->aryOptGrpMem as $val) {
		if ($val["status"] == GRPAUTH_ADMIN) {
?>
	<?php echo $val["user_name"]; ?>：	<?php echo GRPAUTH_ADMIN_NAME; ?>
	<input type="hidden" name="member_status(<?php echo $i; ?>)" value="<?php echo $val["status"]; ?>">
<?php		
		} else {
?>
	<?php echo $val["user_name"]; ?>：
	<label for="r0_<?php echo $i; ?>">
	<input type="radio" id="r0_<?php echo $i; ?>" name="member_status(<?php echo $i; ?>)" value="<?php echo GRPAUTH_NOMEM; ?>"
	 <?php fBtnchk($val["status"],GRPAUTH_NOMEM); ?> <?php echo $tmpDis; ?>><?php echo GRPAUTH_NOMEM_NAME; ?></label>
	<label for="r1_<?php echo $i; ?>">
	<input type="radio" id="r1_<?php echo $i; ?>" name="member_status(<?php echo $i; ?>)" value="<?php echo GRPAUTH_NOAPP; ?>"
	 <?php fBtnchk($val["status"],GRPAUTH_NOAPP); ?> <?php echo $tmpDis; ?>><?php echo GRPAUTH_NOAPP_NAME; ?></label>
	<label for="r2_<?php echo $i; ?>">
	<input type="radio" id="r2_<?php echo $i; ?>" name="member_status(<?php echo $i; ?>)" value="<?php echo GRPAUTH_MEM; ?>"
	 <?php fBtnchk($val["status"],GRPAUTH_MEM); ?> <?php echo $tmpDis; ?>><?php echo GRPAUTH_MEM_NAME; ?></label>
	<label for="r3_<?php echo $i; ?>">
	<input type="radio" id="r3_<?php echo $i; ?>" name="member_status(<?php echo $i; ?>)" value="<?php echo GRPAUTH_MADMIN; ?>"
	 <?php fBtnchk($val["status"],GRPAUTH_MADMIN); ?> <?php echo $tmpDis; ?>><?php echo GRPAUTH_MADMIN_NAME; ?></label>
<?php
		}
?>
	<input type="hidden" name="member_id(<?php echo $i; ?>)" value="<?php echo $val["user_id"]; ?>">
	<input type="hidden" name="member_name(<?php echo $i; ?>)" value="<?php echo $val["user_name"]; ?>">
	<br>
<?php
		$i++;
	}
}

?>


<input type="submit" name="submit2" value="更新" class="submit">
<br><br><br>
<big>このタスクの表示状態を変更</big><br>

<table border="0" cellpadding="1" cellspacing="2">
<tr><td class="tdview">グループ参加に承認が：</td><td class="tdview2">
<?php
	fRdo("assent_flg"	, $this->aryViewMode['assent_flg'],"必要","不要");
?>
</td></tr>
<tr><td class="tdview">表示状態：</td><td class="tdview2">
<?php
	fRdo("view_flg"	, $this->aryViewMode['view_flg'],"公開","メンバーにのみ公開");
?>
</td></tr>
<tr><td class="tdview">優先度：</td><td class="tdview2">
<?php
	fRdo("priority_flg"	, $this->aryViewMode['priority_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">期日：</td><td class="tdview2">
<?php
	fRdo("limit_flg", $this->aryViewMode['limit_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">進捗度：</td><td class="tdview2">
<?php
	fRdo("gains_flg", $this->aryViewMode['gains_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">担当者：</td><td class="tdview2">
<?php
	fRdo("do_user_flg", $this->aryViewMode['do_user_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">登録者：</td><td class="tdview2">
<?php
	fRdo("add_user_flg", $this->aryViewMode['add_user_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">終了タスク：</td><td class="tdview2">
<?php
	fRdo("fintask_flg", $this->aryViewMode['fintask_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">延期タスク：</td><td class="tdview2">
<?php
	fRdo("staytask_flg", $this->aryViewMode['staytask_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">グループメッセージ機能：</td><td class="tdview2">
<?php
	fRdo("grpmail_flg", $this->aryViewMode['grpmail_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">コメント機能：</td><td class="tdview2">
<?php
	fRdo("grpcmnt_flg", $this->aryViewMode['grpcmnt_flg'],"利用する","利用しない");
?>
</td></tr>
<tr><td class="tdview">一覧にコメント数を表示：</td><td class="tdview2">
<?php
	fRdo("grpcmntcnt_flg", $this->aryViewMode['grpcmntcnt_flg'],"利用する","利用しない");
?>
</td></tr>
<tr><td class="tdview">画像添付機能：</td><td class="tdview2">
<?php
	fRdo("grpfile_flg", $this->aryViewMode['grpfile_flg'],"利用する","利用しない");
?>
</td></tr>
<tr><td class="tdview">タスクボリュームを表示：</td><td class="tdview2">
<?php
	fRdo("taskvolume_flg", $this->aryViewMode['taskvolume_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">承認を表示する：</td><td class="tdview2">
<?php
	fRdo("approval_flg", $this->aryViewMode['approval_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">タスク警告：</td><td class="tdview2">
<?php
	fRdo("alert_flg", $this->aryViewMode['alert_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">タスクを<span style="color:<?php echo BGCLR_ALT1; ?>;font-size:200%;">■</span>色で警告表示：</td><td class="tdview2">
<input type="text" name="alert1_days" value="<?php echo $this->aryViewMode['alert1_days']; ?>" size="3" maxlength="3">日以上変化がないもの<br>
<small>※半角数値で記入してください</small><br>
</td></tr>
<tr><td class="tdview">タスクを<span style="color:<?php echo BGCLR_ALT2; ?>;font-size:200%;">■</span>色で警告表示：</td><td class="tdview2">
<input type="text" name="alert2_days" value="<?php echo $this->aryViewMode['alert2_days']; ?>" size="3" maxlength="3">日以上変化がないもの<br>
<small>※半角数値で記入してください</small><br>
</td></tr>
<tr><td class="tdview">タスク削除権限：</td><td class="tdview2">
<?php
	fRdo("delauth_flg", $this->aryViewMode['delauth_flg'],"メンバー","本人 or 管理者");
?>
</td></tr>
<tr><td class="tdview">メンバーへの告知：</td><td class="tdview2">
<textarea name="group_msg" cols="75" rows="3" style="width:100%;"><?php echo $this->aryViewMode['group_msg']; ?></textarea><br>
</td></tr>
<tr><td class="tdview">タスクBoxあたりの表示数：</td><td class="tdview2">
<input type="text" name="taskboxmax" value="<?php echo $this->aryViewMode['taskboxmax']; ?>" size="3" maxlength="3"><br> 
<small>※半角数値で記入してください</small><br>
</td></tr>
<tr><td class="tdview">ページあたりの表示数：</td><td class="tdview2">
<input type="text" name="pagemax" value="<?php echo $this->aryViewMode['pagemax']; ?>" size="3" maxlength="3"> <br>
<small>※半角数値で記入してください</small><br>
</td></tr>
</table>
<input type="submit" name="submit3" value="更新" class="submit">


<br><br>
<big>タスクボックスの属性を変更</big><br>

<?php
// タスクボックス
for ($i = 0; $i < MAX_TASKBOX; $i++) {
	if (!isset($this->aryTaskBox[$i])) {
		$this->aryTaskBox[$i]['taskbox_id'] = "";
		$this->aryTaskBox[$i]['taskbox_name'] = "";
		$this->aryTaskBox[$i]['taskbox_prio'] = "";
		$this->aryTaskBox[$i]['mailsend_flg'] = "";
	}

?>
	タスクボックス   <?php echo $i?>の名前：
	<input type="hidden" name="taskbox_id(<?php echo $i; ?>)" value="<?php echo $this->aryTaskBox[$i]['taskbox_id']; ?>">
	<input type="text" name="taskbox_name(<?php echo $i; ?>)" value="<?php echo $this->aryTaskBox[$i]['taskbox_name']; ?>" maxlength="120">
	優先順位：<select name="taskbox_prio(<?php echo $i; ?>)">
<?php
	for ($j=1;$j<=5;$j++) {
		echo fGetOptPriority($j,$this->aryTaskBox[$i]['taskbox_prio']);
	}
?>
	</select>
	担当者へメールを送信する：<input type="checkbox" name="mailsend_flg(<?php echo $i; ?>)" value="1" <?php if ($this->aryTaskBox[$i]['mailsend_flg']==GRP_SENDMAIL_OK){print "checked";}?>>
	<br>

<?php
}

?>

<div  style="text-align:left;padding-left:150px;">
<small>
※ 優先順位をあげることによりグループ内での表示順序を一時的に変更することができます。<br>
※ 既に登録されているタスクボックスの名前を削除すると、そのタスクボックスがすべて削除されます。
</small>
</div>
<input type="hidden" name="group_no" value="<?php echo $this->group_no; ?>">
<input type="hidden" name="csrf" value="<?php echo $this->csrf; ?>">
<input type="hidden" name="mode" value="<?php echo GRP_CLASS_EDIT; ?>">
<input type="submit" name="submit1" value="更新" class="submit">

</form>

<br><br>
<hr size="5">
<br>

<form action="grpmst.php" method="post">
<big>終了タスクの一括破棄</big><br>
ステータス状態が終了になって
<input type="text" name="delspan" class="delspan" value="20" maxlength="3" size="3"> 日 以上経過しているものを一括で削除する。<br>
<small>※半角数値で記入してください</small><br>
<input type="hidden" name="group_no" value="<?php echo $this->group_no; ?>">
<input type="hidden" name="csrf" value="<?php echo $this->csrf; ?>">
<input type="hidden" name="mode" value="<?php echo GRP_CLASS_SPANDEL; ?>">
<input type="submit" value="タスクの一括破棄" class="submit">
</form>


<br><br><br>
<a href="tasklist.php?group_no=<?php echo $this->group_no; ?>">もどる</a>

</div>


<?php
	// フッター
	include_once(TODOTASK_VIEW_DIR.'/common/footer.inc.php');
?>

==> todotask2.1.0.zip: todotask2/app/views/grp/mst.php <==
<?php
	// ページ描画
	// ヘッダ
	require_once(TODOTASK_VIEW_DIR.'/common/header.inc.php');

function fBtnchk($flg,$chkval) {
	if($flg==$chkval) {
		print "checked";
	}
}
function fRdo($name, $flg,$on_label,$off_label) {
?>
	<label for="<?php echo $name.VIEW_ON; ?>">
	 <input type="radio" id="<?php echo $name.VIEW_ON; ?>" name="<?php echo $name; ?>" value="<?php echo VIEW_ON; ?>" <?php fBtnchk($flg,VIEW_ON); ?>><?php echo $on_label; ?>
	</label>
	<label for="<?php echo $name.VIEW_OFF; ?>">
	 <input type="radio" id="<?php echo $name.VIEW_OFF; ?>" name="<?php echo $name; ?>" value="<?php echo VIEW_OFF; ?>" <?php fBtnchk($flg,VIEW_OFF); ?>><?php echo $off_label; ?>
	</label>
<?php
}
function fGetOptPriority($cnt,$priority) {
	$tmp = "";
	$selected = "";
	if ($priority == $cnt || ($priority == "" && $cnt == 1 )){
		$selected = "selected";
	}
	for ($i=1;$i<=$cnt;$i++) {
		$tmp .= TASK_PRIORITY;  
	}
	return "<option value=\"".$cnt."\"" . $selected . ">".$tmp."</option>";
}

?>
<div align="center">
<div class="noticediv">
ここでグループの状態を管理することにより、表示状態や機能のon/offをコントロールできます。
</div>

<big class="err_msg"><?php echo $this->art_msg; ?></big>


<form action="./grpmst.php" method="post">

<?php

if ($this->memLv == GRPAUTH_ADMIN) {
?>
	<br>
	<big>このグループの基本情報の更新</big><br>
	<table border="0" cellpadding="1" cellspacing="2">
	<tr><td class="tdview">グループ名：</td><td class="tdview2">
	<input type="text" name="group_name" value="<?php echo $this->aryGrpInfo["group_name"]; ?>"><br>
	</td></tr>

	<tr><td class="tdview">グループ情報：</td><td class="tdview2">
	<input type="text" name="group_note" value="<?php echo $this->aryGrpInfo["group_note"]; ?>"><br>
	</td></tr>
	<tr><td class="tdview">グループ重要度：</td><td class="tdview2">
	<select name="group_prio">
<?php
	for ($j=1;$j<=5;$j++) {
		echo fGetOptPriority($j,$this->aryGrpInfo["group_prio"]);
	}
?>
	</select>
	</td></tr>
	</table>

	<br><small>※グループの脱退や削除はユーザー情報のページからおこなってください。</small><br>
	<input type="submit" name="submit5" value="更新" class="submit">
	<br>
	<br>
<?php
}
?>


<?php
if (count($this->aryOptGrpMem)>0) {
?>
	<br>
	<big>このグループの参加メンバー情報</big><br>
<?php
	$i = 0;
	// 管理者以外変更できないように
	$tmpDis = "DISABLED";
	if (($this->memLv == GRPAUTH_ADMIN)||($this->memLv == GRPAUTH_MADMIN)) {
		$tmpDis = "";
	}
	foreach ($this->aryOptGrpMem as $val) {
		if ($val["status"] == GRPAUTH_ADMIN) {
?>
	<?php echo $val["user_name"]; ?>：	<?php echo GRPAUTH_ADMIN_NAME; ?>
	<input type="hidden" name="member_status(<?php echo $i; ?>)" value="<?php echo $val["status"]; ?>">
<?php		
		} else {
?>
	<?php echo $val["user_name"]; ?>：
	<label for="r0_<?php echo $i; ?>">
	<input type="radio" id="r0_<?php echo $i; ?>" name="member_status(<?php echo $i; ?>)" value="<?php echo GRPAUTH_NOMEM; ?>"
	 <?php fBtnchk($val["status"],GRPAUTH_NOMEM); ?> <?php echo $tmpDis; ?>><?php echo GRPAUTH_NOMEM_NAME; ?></label>
	<label for="r1_<?php echo $i; ?>">
	<input type="radio" id="r1_<?php echo $i; ?>" name="member_status(<?php echo $i; ?>)" value="<?php echo GRPAUTH_NOAPP; ?>"
	 <?php fBtnchk($val["status"],GRPAUTH_NOAPP); ?> <?php echo $tmpDis; ?>><?php echo GRPAUTH_NOAPP_NAME; ?></label>
	<label for="r2_<?php echo $i; ?>">
	<input type="radio" id="r2_<?php echo $i; ?>" name="member_status(<?php echo $i; ?>)" value="<?php echo GRPAUTH_MEM; ?>"
	 <?php fBtnchk($val["status"],GRPAUTH_MEM); ?> <?php echo $tmpDis; ?>><?php echo GRPAUTH_MEM_NAME; ?></label>
	<label for="r3_<?php echo $i; ?>">
	<input type="radio" id="r3_<?php echo $i; ?>" name="member_status(<?php echo $i; ?>)" value="<?php echo GRPAUTH_MADMIN; ?>"
	 <?php fBtnchk($val["status"],GRPAUTH_MADMIN); ?> <?php echo $tmpDis; ?>><?php echo GRPAUTH_MADMIN_NAME; ?></label>
<?php
		}
?>
	<input type="hidden" name="member_id(<?php echo $i; ?>)" value="<?php echo $val["user_id"]; ?>">
	<input type="hidden" name="member_name(<?php echo $i; ?>)" value="<?php echo $val["user_name"]; ?>">
	<br>
<?php
		$i++;
	}
}

?>


<input type="submit" name="submit2" value="更新" class="submit">
<br><br><br>
<big>このタスクの表示状態を変更</big><br>

<table border="0" cellpadding="1" cellspacing="2">
<tr><td class="tdview">グループ参加に承認が：</td><td class="tdview2">
<?php
	fRdo("assent_flg"	, $this->aryViewMode['assent_flg'],"必要","不要");
?>
</td></tr>
<tr><td class="tdview">表示状態：</td><td class="tdview2">
<?php
	fRdo("view_flg"	, $this->aryViewMode['view_flg'],"公開","メンバーにのみ公開");
?>
</td></tr>
<tr><td class="tdview">タイトル秘密モード：</td><td class="tdview2">
<?php
	fRdo("secret_flg"	, $this->aryViewMode['secret_flg'],"秘密","普通");
?>
</td></tr>
<tr><td class="tdview">優先度：</td><td class="tdview2">
<?php
	fRdo("priority_flg"	, $this->aryViewMode['priority_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">期日：</td><td class="tdview2">
<?php
	fRdo("limit_flg", $this->aryViewMode['limit_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">進捗度：</td><td class="tdview2">
<?php
	fRdo("gains_flg", $this->aryViewMode['gains_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">担当者：</td><td class="tdview2">
<?php
	fRdo("do_user_flg", $this->aryViewMode['do_user_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">登録者：</td><td class="tdview2">
<?php
	fRdo("add_user_flg", $this->aryViewMode['add_user_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">終了タスク：</td><td class="tdview2">
<?php
	fRdo("fintask_flg", $this->aryViewMode['fintask_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">延期タスク：</td><td class="tdview2">
<?php
	fRdo("staytask_flg", $this->aryViewMode['staytask_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">グループメッセージ機能：</td><td class="tdview2">
<?php
	fRdo("grpmail_flg", $this->aryViewMode['grpmail_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">コメント機能：</td><td class="tdview2">
<?php
	fRdo("grpcmnt_flg", $this->aryViewMode['grpcmnt_flg'],"利用する","利用しない");
?>
</td></tr>
<tr><td class="tdview">一覧にコメント数を表示：</td><td class="tdview2">
<?php
	fRdo("grpcmntcnt_flg", $this->aryViewMode['grpcmntcnt_flg'],"利用する","利用しない");
?>
</td></tr>
<tr><td class="tdview">画像添付機能：</td><td class="tdview2">
<?php
	fRdo("grpfile_flg", $this->aryViewMode['grpfile_flg'],"利用する","利用しない");
?>
</td></tr>
<tr><td class="tdview">タスクボリュームを表示：</td><td class="tdview2">
<?php
	fRdo("taskvolume_flg", $this->aryViewMode['taskvolume_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">承認を表示する：</td><td class="tdview2">
<?php
	fRdo("approval_flg", $this->aryViewMode['approval_flg'],"表示する","表示しない");
?>
</td></tr>
<tr><td class="tdview">タスク警告：</td><td class="tdview2">
<?php
	fRdo("alert_flg", $this->aryViewMode['alert_flg'],"表示する","表示しない");
?>
</td></tr>
<!--
<tr><td class="tdview">タスク警告メールを送る：</td><td class="tdview2">
<?php
	fRdo("alertmail_flg", $this->aryViewMode['alertmail_flg'],"送る","送らない");
?>
※機能未実装です
</td></tr>
-->
<tr><td class="tdview">タスクを<span style="color:<?php echo BGCLR_ALT1; ?>;font-size:200%;">■</span>色で警告表示：</td><td class="tdview2">
<input type="text" name="alert1_days" value="<?php echo $this->aryViewMode['alert1_days']; ?>" size="3" maxlength="3">日以上変化がないもの<br>
<small>※半角数値で記入してください</small><br>
</td></tr>
<tr><td class="tdview">タスクを<span style="color:<?php echo BGCLR_ALT2; ?>;font-size:200%;">■</span>色で警告表示：</td><td class="tdview2">
<input type="text" name="alert2_days" value="<?php echo $this->aryViewMode['alert2_days']; ?>" size="3" maxlength="3">日以上変化がないもの<br>
<small>※半角数値で記入してください</small><br>
</td></tr>
<tr><td class="tdview">タスク削除権限：</td><td class="tdview2">
<?php
	fRdo("delauth_flg", $this->aryViewMode['delauth_flg'],"メンバー","本人 or 管理者");
?>
</td></tr>
<tr><td class="tdview">メンバーへの告知：</td><td class="tdview2">
<textarea name="group_msg" cols="75" rows="3" style="width:100%;"><?php echo $this->aryViewMode['group_msg']; ?></textarea><br>
</td></tr>
<tr><td class="tdview">タスクBoxあたりの表示数：</td><td class="tdview2">
<input type="text" name="taskboxmax" value="<?php echo $this->aryViewMode['taskboxmax']; ?>" size="3" maxlength="3"><br> 
<small>※半角数値で記入してください</small><br>
</td></tr>
<tr><td class="tdview">ページあたりの表示数：</td><td class="tdview2">
<input type="text" name="pagemax" value="<?php echo $this->aryViewMode['pagemax']; ?>" size="3" maxlength="3"> <br>
<small>※半角数値で記入してください</small><br>
</td></tr>
</table>
<input type="submit" name="submit3" value="更新" class="submit">


<br><br>
<big>タスクボックスの属性を変更</big><br>

<?php
// タスクボックス
for ($i = 0; $i < MAX_TASKBOX; $i++) {
	if (!isset($this->aryTaskBox[$i])) {
		$this->aryTaskBox[$i]['taskbox_id'] = "";
		$this->aryTaskBox[$i]['taskbox_name'] = "";
		$this->aryTaskBox[$i]['taskbox_prio'] = "";
		$this->aryTaskBox[$i]['mailsend_flg'] = "";
	}

?>
	タスクボックス   <?php echo $i?>の名前：
	<input type="hidden" name="taskbox_id(<?php echo $i; ?>)" value="<?php echo $this->aryTaskBox[$i]['taskbox_id']; ?>">
	<input type="text" name="taskbox_name(<?php echo $i; ?>)" value="<?php echo $this->aryTaskBox[$i]['taskbox_name']; ?>" maxlength="120">
	優先順位：<select name="taskbox_prio(<?php echo $i; ?>)">
<?php
	for ($j=1;$j<=5;$j++) {
		echo fGetOptPriority($j,$this->aryTaskBox[$i]['taskbox_prio']);
	}
?>
	</select>
	担当者へメールを送信する：<input type="checkbox" name="mailsend_flg(<?php echo $i; ?>)" value="1" <?php if ($this->aryTaskBox[$i]['mailsend_flg']==GRP_SENDMAIL_OK){print "checked";}?>>
	<br>

<?php
}

?>

<div  style="text-align:left;padding-left:150px;">
<small>
※ 優先順位をあげることによりグループ内での表示順序を一時的に変更することができます。<br>
※ 既に登録されているタスクボックスの名前を削除すると、そのタスクボックスがすべて削除されます。
</small>
</div>
<input type="hidden" name="group_no" value="<?php echo $this->group_no; ?>">
<input type="hidden" name="csrf" value="<?php echo $this->csrf; ?>">
<input type="hidden" name="mode" value="<?php echo GRP_CLASS_EDIT; ?>">
<input type="submit" name="submit1" value="更新" class="submit">

</form>

<br><br>
<hr size="5">
<br>

<form action="grpmst.php" method="post">
<big>終了タスクの一括破棄</big><br>
ステータス状態が終了になって
<input type="text" name="delspan" class="delspan" value="20" maxlength="3" size="3"> 日 以上経過しているものを一括で削除する。<br>
<small>※半角数値で記入してください</small><br>
<input type="hidden" name="group_no" value="<?php echo $this->group_no; ?>">
<input type="hidden" name="csrf" value="<?php echo $this->csrf; ?>">
<input type="hidden" name="mode" value="<?php echo GRP_CLASS_SPANDEL; ?>">
<input type="submit" value="タスクの一括破棄" class="submit">
</form>


<br><br><br>
<a href="tasklist.php?group_no=<?php echo $this->group_no; ?>">もどる</a>

</div>


<?php
	// フッター
	include_once(TODOTASK_VIEW_DIR.'/common/footer.inc.php');
?>
